@@ -2,7 +2,7 @@ package Function::Runner;
 
 use strict; use warnings; use utf8; use 5.10.0;
 use Data::Dumper;
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 
 my $PEEK_LEVEL = 5;     # Disallow peeks below this level
@@ -94,12 +94,12 @@ sub _mk_fn_map {
                 next;
             }
 
-            # Guard: The given symbol e.g. 'hello' must be a coderef in
-            #        the calling package's symbol table
-            my $sym_ref = exists($tab->{$sym}) ? ref($tab->{$sym}) : '?';
-            peek 3, "Func: $res has ref: \"$sym_ref\"";
-            _die("\"$sym\" not a coderef in \"$pkg\"")
-                unless $sym_ref eq 'CODE';
+            # Guard: The given symbol e.g. 'hello' must be defined as a
+            #        function in the calling package
+            my $is_code = eval 'defined &'.$pkg.'::'.$sym ? 1 : 0;
+            peek 3, "Func: $res is code: \"$is_code\"";
+            _die("\n\n"."\"$sym\" not a coderef in \"$pkg\"")
+                unless $is_code;
 
             # Add mapping of symbol to coderef
             $fn_map->{$sym} = $tab->{$sym};
@@ -223,8 +223,8 @@ sub _die {
     # Case called as a function, message is the first arg
     if (ref $o eq '') { $msg = $o }
 
-    peek 999, $LOG;
-    die "\n  $msg\n    (pkg: $pkg - file: $file - line: $line)\n     ";
+    die Dumper($LOG)
+        ."\n  $msg\n    (pkg: $pkg - file: $file - line: $line)\n     ";
 }
 
 
